@@ -1,5 +1,5 @@
 /* grecs - Gray's Extensible Configuration System -*- c -*-
-   Copyright (C) 2007-2021 Sergey Poznyakoff
+   Copyright (C) 2007-2025 Sergey Poznyakoff
 
    Grecs is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -26,8 +26,10 @@ void *grecs_malloc(size_t size);
 void *grecs_zalloc(size_t size);
 void *grecs_calloc(size_t nmemb, size_t size);
 void *grecs_realloc(void *ptr, size_t size);
+void *grecs_2nrealloc(void *ptr, size_t *pn, size_t elsize);
 void grecs_alloc_die(void);
 char *grecs_strdup(const char *str);
+char *grecs_strndup(const char *str, size_t len);
 void grecs_free(void *ptr);
 
 #endif
