@@ -1,5 +1,5 @@
 /* Environment modification functions for GNU Pies.
-   Copyright (C) 2019-2025 Sergey Poznyakoff
+   Copyright (C) 2019-2026 Sergey Poznyakoff
 
    GNU Pies is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -67,11 +67,14 @@ environ_create (char **def)
 void
 environ_free (environ_t *env)
 {
-  size_t i;
-  for (i = 0; i < env->env_count; i++)
-    free (env->env_base[i]);
-  free (env->env_base);
-  free (env);
+  if (env)
+    {
+      size_t i;
+      for (i = 0; i < env->env_count; i++)
+	free (env->env_base[i]);
+      free (env->env_base);
+      free (env);
+    }
 }
 
 static ssize_t
