@@ -1,5 +1,5 @@
 /* This file is part of GNU Pies.
-   Copyright (C) 2016-2025 Sergey Poznyakoff
+   Copyright (C) 2016-2026 Sergey Poznyakoff
 
    GNU Pies is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -605,7 +605,7 @@ components_list_shutdown_sequence (void)
 }
 
 /*
- * Computes array if shutdown sequence numbers and stores it in RET.
+ * Computes array of shutdown sequence numbers and stores it in RET.
  * Returns number of elements in the computed array.
  */
 size_t
@@ -626,6 +626,7 @@ components_shutdown_sequence_numbers (unsigned long **ret)
 	}
     }
  end:
+  free (a);
   *ret = idx;
   return i + 1;
 }
