@@ -1,5 +1,5 @@
 /* This file is part of GNU Pies.
-   Copyright (C) 2008-2025 Sergey Poznyakoff
+   Copyright (C) 2008-2026 Sergey Poznyakoff
 
    GNU Pies is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -19,9 +19,9 @@
 #include <configmake.h>
 #include "meta1parse.h"
 #include "grecsasrt.h"
+#include "parseopt.h"
 
 int preprocess_only;		/* Preprocess config, do nothing more */
-int lint_mode;			/* Test configuration syntax and exit */
 int log_to_stderr_only;                /* Use only stderr for logging */
 struct pies_privs pies_privs;
 int foreground;
@@ -45,7 +45,17 @@ char *statedir = DEFAULT_STATE_DIR;
 char *instance;
 char *pidfile;
 char *qotdfile;
-int inetd_mode;
+
+enum
+  {
+    MODE_PIES,
+    MODE_LINT,
+    MODE_INETD,
+    MODE_TELINIT
+  };
+int pies_mode;
+
+char *incpath = DEFAULT_INCLUDE_PATH;
 mode_t pies_umask = 0;
 unsigned long shutdown_timeout = 5;
 size_t default_max_rate;
@@ -386,7 +396,7 @@ create_action (struct component *comp,
     {
       cond_list = grecs_list_create ();
       cond_list->free_entry = listel_dispose;
-      
+
       for (i = 0; i < argc; i++)
 	{
 	  struct status_cond *sc;
@@ -408,7 +418,7 @@ create_action (struct component *comp,
 		  len = strlen (arg);
 		}
 	    }
-	  
+
 	  if (isdigit (arg[0]))
 	    {
 	      char *p;
@@ -771,7 +781,7 @@ _cb_env_clear (enum grecs_callback_command cmd,
       grecs_error (&value->locus, 0, "%s", _("unexpected argument"));
       return 1;
     }
-  
+
   if (envop_entry_add (envop_ptr, envop_clear, NULL, NULL))
     grecs_error (locus, errno, "envop_entry_add");
 
@@ -1213,6 +1223,7 @@ str_to_cf (const char *string, int *flags)
     { "nullinput", CF_NULLINPUT },
     { "shell", CF_SHELL },
     { "expandenv", CF_EXPANDENV },
+    { "deansify", CF_DEANSIFY },
     { NULL }
   };
 
@@ -1297,7 +1308,7 @@ _cb_signal (enum grecs_callback_command cmd,
   *(int*)varptr = n;
   return 0;
 }
-  
+
 struct grecs_keyword component_keywords[] = {
   {"mode",
    N_("mode"),
@@ -1498,7 +1509,7 @@ struct grecs_keyword component_keywords[] = {
    N_("Modify program environment."),
    grecs_type_section, GRECS_DFLT,
    NULL, offsetof (struct component, envop),
-   cb_env_section_parser, NULL, cb_env_keywords 
+   cb_env_section_parser, NULL, cb_env_keywords
    },
   {"env",
    N_("arg: list"),
@@ -1630,7 +1641,7 @@ static struct grecs_keyword syslog_kw[] = {
    N_("Syslog device: either absolute pathname of the socket file, "
       "or an IPv4 address and optional port, separated with a colon"),
    grecs_type_string, GRECS_CONST,
-   NULL, 0, cb_syslog_dev },   
+   NULL, 0, cb_syslog_dev },
   {"facility",
    N_("name"),
    N_("Set syslog facility. Arg is one of the following: user, daemon, "
@@ -1644,6 +1655,14 @@ static struct grecs_keyword syslog_kw[] = {
   {"fallback-file", N_("filename"), N_("Name of the fallback log file"),
    grecs_type_string, GRECS_DFLT,
    &pies_fallback_file},
+  {"message-queue-size", N_("arg"), N_("Max. capacity of the log message queue"),
+   grecs_type_size, GRECS_DFLT,
+   &pies_log_max_queue },
+  {"fallback-ignore-failures",
+   N_("arg"),
+   N_("Ignore errors during writes to the fallback file"),
+   grecs_type_bool, GRECS_DFLT,
+   &pies_fallback_ignore_failures},
 #if 0
   /* This is reserved for future use */
   {
@@ -1692,7 +1711,7 @@ struct grecs_keyword pies_keywords[] = {
    N_("Modify program environment."),
    grecs_type_section, GRECS_DFLT,
    &pies_envop, 0,
-   cb_env_section_parser, NULL, cb_env_keywords 
+   cb_env_section_parser, NULL, cb_env_keywords
    },
   {"control",
    NULL,
@@ -1857,7 +1876,7 @@ void
 config_init (void)
 {
   grecs_preprocessor = DEFAULT_PREPROCESSOR;
-  
+
   grecs_log_to_stderr = log_to_stderr_only;
   pies_identity_mechanism_register (&system_identity_mechanism);
 #ifdef WITH_PAM
@@ -1938,9 +1957,6 @@ pies_reread_config (void)
 
 static struct config_syntax *current_syntax = &config_syntax_tab[CONF_PIES];
 
-#include "cmdline.h"
-
-
 static int action = ACTION_CONT;
 static int children_op = PIES_CHLD_NONE;
 
@@ -2311,11 +2327,32 @@ set_mailer_argcv (void)
   wordsplit_free (&ws);
 }
 
+#ifdef INIT_EMU
+# warning "pies compiled with init emulation code"
+static char init_emu_help[] =
+  "    To enable init emulation code, define environment variable\n"
+  "         INIT_EMU=<inittab>[:<config>]\n"
+  "    where <inittab> and <config> are names of the inittab and\n"
+  "    Pies configuration files, correspondingly.\n"
+  "\n"
+  "    To override the default FIFO name, define:\n"
+  "         INIT_FIFO=<pathname>\n";
+#endif
+
+static inline void
+init_emu_fifo_setup (void)
+{
+#ifdef INIT_EMU
+  init_fifo = getenv ("INIT_FIFO");
+  if (!init_fifo)
+    init_fifo = "/tmp/initctl";
+#endif
+}
+
 static inline int
 init_emu (void)
 {
 #ifdef INIT_EMU
-# warning "pies compiled with init emulation code"
   char *emu = getenv ("INIT_EMU");
   if (emu)
     {
@@ -2326,9 +2363,7 @@ init_emu (void)
       config_file_add_type (CONF_PIES,
 			    piesinit ? piesinit : "/etc/pies.init");
 
-      init_fifo = getenv ("INIT_FIFO");
-      if (!init_fifo)
-	init_fifo = "/tmp/initctl";
+      init_emu_fifo_setup ();
 
       init_process = 1;
       fprintf (stderr, "%s: running in init emulation mode\n", program_name);
@@ -2337,14 +2372,7 @@ init_emu (void)
   else
     {
       fprintf (stderr, "%s: Notice:\n", program_name);
-      fprintf (stderr,
-	       "    To enable init emulation code, define environment variable\n"
-	       "         INIT_EMU=<inittab>[:<config>]\n"
-	       "    where <inittab> and <config> are names of the inittab and\n"
-	       "    Pies configuration files, correspondingly.\n"
-	       "\n"
-	       "    To override the default FIFO name, define:\n"
-	       "         INIT_FIFO=<pathname>\n");
+      fprintf (stderr, "%s", init_emu_help);
       fprintf (stderr, "%s: End of notice\n", program_name);
     }
 #endif
@@ -2400,7 +2428,7 @@ is_docker (void)
   };
   enum { state_init = 0, state_success = 11, state_eof = 12 };
   int state = state_init;
-	  
+
   fp = fopen ("/proc/self/cgroup", "r");
   if (!fp)
     return 0;
@@ -2439,7 +2467,7 @@ no_init_option (int argc, char **argv)
 
 /*
  * init_detect - detect if we're run as init process.
- * 
+ *
  * Pies runs as init process if (1) it has PID 1, (2) is not started as docker
  * entrypoint, and (3) the `--no-init' command line option is not given.
  *
@@ -2467,6 +2495,538 @@ init_detect (int argc, char **argv)
     }
 }
 
+enum
+{
+  OPT_CONFIG_HELP = 256,
+  OPT_FORCE,
+  OPT_FOREGROUND,
+  OPT_NO_INIT,
+  OPT_INSTANCE,
+  OPT_RATE,
+  OPT_STDERR,
+  OPT_SYNTAX,
+  OPT_SYSLOG,
+  OPT_PREPROCESSOR,
+  OPT_NO_PREPROCESSOR,
+  OPT_NO_INCLUDE,
+  OPT_DUMP_DEPMAP,
+  OPT_TRACE_DEPEND,
+  OPT_TRACE_PREREQ,
+  OPT_LIST_SHUTDOWN_SEQUENCE,
+  OPT_SOURCE_INFO
+};
+
+static int
+optset_config_file (struct parseopt *po, struct optdef *opt, char *arg)
+{
+  config_file_add (current_syntax, arg);
+  return 0;
+}
+
+static int
+optset_config_help (struct parseopt *po, struct optdef *opt, char *arg)
+{
+  config_help ();
+  exit (0);
+}
+
+static int
+optset_current_syntax (struct parseopt *po, struct optdef *opt, char *arg)
+{
+  current_syntax = str_to_config_syntax (arg);
+  if (!current_syntax)
+    {
+      logmsg (LOG_ERR, _("unknown syntax type: %s"), arg);
+      exit (EX_USAGE);
+    }
+  return 0;
+}
+
+static int
+optset_pp_option (struct parseopt *po, struct optdef *opt, char *arg)
+{
+  char optbuf[3] = { '-', 0, 0 };
+  while (opt->opt_name[1])
+    {
+      ++opt;
+      if (!(opt->opt_flags & OPTFLAG_ALIAS))
+	{
+	  logmsg (LOG_CRIT, "INTERNAL ERROR at %s:%d, please report",
+		  __FILE__, __LINE__);
+	  exit (EX_SOFTWARE);
+	}
+    }
+  optbuf[1] = opt->opt_name[0];
+  pp_add_option (optbuf, arg);
+  return 0;
+}
+
+static struct optdef *mode_opt;
+
+static void
+set_mode (struct parseopt *po, struct optdef *opt, int mode)
+{
+  if (mode_opt != NULL)
+    {
+      po->po_error (po, PO_MSG_ERR,
+		    _("conflicting options: %s%s and %s%s"),
+		    option_dash (po, mode_opt), mode_opt->opt_name,
+		    option_dash (po, opt), opt->opt_name);
+      exit (EX_USAGE);
+    }
+  pies_mode = mode;
+}
+
+static int
+optset_inetd_mode (struct parseopt *po, struct optdef *opt, char *arg)
+{
+  if (!instance)
+    instance = "inetd";
+  current_syntax = &config_syntax_tab[CONF_INETD];
+  set_mode (po, opt, MODE_INETD);
+  return 0;
+}
+
+static int
+optset_telinit_mode (struct parseopt *po, struct optdef *opt, char *arg)
+{
+  set_mode (po, opt, MODE_TELINIT);
+  po->po_eopt = 1;
+  log_to_stderr_only = 1;
+  return 0;
+}
+
+static int
+optset_lint_mode (struct parseopt *po, struct optdef *opt, char *arg)
+{
+  set_mode (po, opt, MODE_LINT);
+  log_to_stderr_only = 1;
+  return 0;
+}
+
+static struct optdef options[] = {
+  {
+    .opt_flags = OPTFLAG_DOC,
+    .opt_doc = N_("Operation Mode")
+  },
+
+  {
+    .opt_name = "config-file",
+    .opt_argdoc = N_("FILE"),
+    .opt_doc = N_("use FILE instead of the default configuration"),
+    .opt_set = optset_config_file
+  },
+  {
+    .opt_name = "c",
+    .opt_flags = OPTFLAG_ALIAS
+  },
+
+  {
+    .opt_name = "config-help",
+    .opt_doc = N_("show configuration file summary"),
+    .opt_code = OPT_CONFIG_HELP,
+    .opt_set = optset_config_help
+  },
+
+  {
+    .opt_name = "E",
+    .opt_doc = N_("preprocess configuration file and exit"),
+    .opt_set = optset_true,
+    .opt_ptr = &preprocess_only
+  },
+
+  {
+    .opt_name = "force",
+    .opt_doc = N_("force startup even if another instance may be running"),
+    .opt_code = OPT_FORCE,
+    .opt_set = optset_true,
+    .opt_ptr = &force_option
+  },
+
+  {
+    .opt_name = "foreground",
+    .opt_doc = N_("remain in foreground"),
+    .opt_code = OPT_FOREGROUND
+  },
+
+  {
+    .opt_name = "no-init",
+    .opt_doc = N_("don't suppose SysV init mode if PID is 1"),
+    .opt_code = OPT_NO_INIT
+    /* NOTE: handled separately by init_detect */
+  },
+
+  {
+    .opt_name = "inetd",
+    .opt_doc = N_("run in inetd mode"),
+    .opt_set = optset_inetd_mode
+  },
+  {
+    .opt_name = "i",
+    .opt_flags = OPTFLAG_ALIAS
+  },
+
+  {
+    .opt_name = "instance",
+    .opt_argdoc = N_("NAME"),
+    .opt_doc = N_("set instance name"),
+    .opt_code = OPT_INSTANCE,
+    .opt_set = optset_string_copy,
+    .opt_ptr = &instance
+  },
+
+  {
+    .opt_name = "rate",
+    .opt_argdoc = N_("NUMBER"),
+    .opt_doc = N_("set default maximum rate for inetd-style components"),
+    .opt_code = OPT_RATE,
+    .opt_set = optset_ulong,
+    .opt_ptr = &default_max_rate
+  },
+
+  {
+    .opt_name = "stderr",
+    .opt_doc = N_("log to stderr"),
+    .opt_code = OPT_STDERR,
+    .opt_set = optset_true,
+    .opt_ptr = &log_to_stderr_only
+  },
+
+  {
+    .opt_name = "syntax",
+    .opt_argdoc = N_("{pies|meta1|inetd|inittab}"),
+    .opt_doc = N_("expect configuration files in the given syntax"),
+    .opt_code = OPT_SYNTAX,
+    .opt_set = optset_current_syntax
+  },
+
+  {
+    .opt_name = "syslog",
+    .opt_doc = N_("log to syslog"),
+    .opt_code = OPT_SYSLOG,
+    .opt_set = optset_false,
+    .opt_ptr = &log_to_stderr_only
+  },
+
+  {
+    .opt_name = "lint",
+    .opt_doc = N_("parse configuration file and exit"),
+    .opt_set = optset_lint_mode
+  },
+  {
+    .opt_name = "t",
+    .opt_flags = OPTFLAG_ALIAS
+  },
+
+  {
+    .opt_name = "telinit",
+    .opt_doc = N_("telinit command: run \"pies -T --help\" for help"),
+    .opt_set = optset_telinit_mode
+  },
+  {
+    .opt_name = "T",
+    .opt_flags = OPTFLAG_ALIAS
+  },
+
+  {
+    .opt_flags = OPTFLAG_DOC,
+    .opt_doc = N_("Preprocessor")
+  },
+
+  {
+    .opt_name = "preprocessor",
+    .opt_argdoc = N_("COMMAND"),
+    .opt_doc = N_("use COMMAND instead of the default preprocessor"),
+    .opt_code = OPT_PREPROCESSOR,
+    .opt_set = optset_string_copy,
+    .opt_ptr = &grecs_preprocessor
+  },
+
+  {
+    .opt_name = "no-preprocessor",
+    .opt_doc = N_("disable preprocessing"),
+    .opt_code = OPT_NO_PREPROCESSOR,
+    .opt_set = optset_string_copy, /* This sets grecs_preprocessor to NULL. */
+    .opt_ptr = &grecs_preprocessor
+  },
+
+  {
+    .opt_name = "include-directory",
+    .opt_argdoc = N_("DIR"),
+    .opt_doc = N_("add include directory"),
+    .opt_set = optset_pp_option
+  },
+  {
+    .opt_name = "I",
+    .opt_flags = OPTFLAG_ALIAS
+  },
+
+  {
+    .opt_name = "no-include",
+    .opt_doc = N_("clear default preprocessor search path"),
+    .opt_code = OPT_NO_INCLUDE,
+    .opt_set = optset_string_copy, /* Set incpath to NULL. */
+    .opt_ptr = &incpath
+  },
+
+  {
+    .opt_name = "define",
+    .opt_argdoc = N_("NAME[=VALUE]"),
+    .opt_doc =
+    N_("define a preprocessor symbol NAME as having VALUE or empty"),
+    .opt_set = optset_pp_option
+  },
+  {
+    .opt_name = "D",
+    .opt_flags = OPTFLAG_ALIAS
+  },
+
+  {
+    .opt_name = "undefine",
+    .opt_argdoc = N_("NAME"),
+    .opt_doc = N_("undefine a preprocessor symbol NAME"),
+    .opt_set = optset_pp_option
+  },
+  {
+    .opt_name = "U",
+    .opt_flags = OPTFLAG_ALIAS
+  },
+
+  {
+    .opt_flags = OPTFLAG_DOC,
+    .opt_doc = N_("Component Management")
+  },
+
+  {
+    .opt_name = "reload",
+    .opt_doc = N_("reload the running instance of pies"),
+  },
+  {
+    .opt_name = "r",
+    .opt_flags = OPTFLAG_ALIAS
+  },
+  {
+    .opt_name = "hup",
+    .opt_flags = OPTFLAG_ALIAS
+  },
+
+  {
+    .opt_name = "restart-component",
+    .opt_doc = N_("restart components named in the command line"),
+  },
+  {
+    .opt_name = "R",
+    .opt_flags = OPTFLAG_ALIAS
+  },
+
+  {
+    .opt_name = "status",
+    .opt_doc = N_("display info about the running instance"),
+  },
+  {
+    .opt_name = "s",
+    .opt_flags = OPTFLAG_ALIAS
+  },
+
+  {
+    .opt_name = "stop",
+    .opt_doc = N_("stop the running instance"),
+  },
+  {
+    .opt_name = "S",
+    .opt_flags = OPTFLAG_ALIAS
+  },
+
+  {
+    .opt_flags = OPTFLAG_DOC,
+    .opt_doc = N_("Debugging and Additional Diagnostics")
+  },
+
+  {
+    .opt_name = "dump-depmap",
+    .opt_doc = N_("dump dependency map"),
+    .opt_code = OPT_DUMP_DEPMAP
+  },
+
+  {
+    .opt_name = "trace-depend",
+    .opt_doc = N_("trace dependencies"),
+    .opt_code = OPT_TRACE_DEPEND
+  },
+
+  {
+    .opt_name = "trace-prereq",
+    .opt_doc = N_("trace prerequisites"),
+    .opt_code = OPT_TRACE_PREREQ
+  },
+
+  {
+    .opt_name = "list-shutdown-sequence",
+    .opt_doc = N_("list components in shutdown sequence ordering"),
+    .opt_code = OPT_LIST_SHUTDOWN_SEQUENCE
+  },
+
+  {
+    .opt_name = "source-info",
+    .opt_doc = N_("show source info with debugging messages"),
+    .opt_code = OPT_SOURCE_INFO,
+    .opt_set = optset_true,
+    .opt_ptr = &source_info_option
+  },
+
+  {
+    .opt_name = "debug",
+    .opt_argdoc = N_("LEVEL"),
+    .opt_doc = N_("set debug verbosity level"),
+    .opt_set = optset_uint,
+    .opt_ptr = &debug_level
+  },
+  {
+    .opt_name = "x",
+    .opt_flags = OPTFLAG_ALIAS
+  },
+
+  { NULL }
+}, *optdef[] = { options, NULL };
+
+static void
+setopt (struct parseopt *po, int code, char *arg)
+{
+  switch (code)
+    {
+    case OPT_FOREGROUND:
+      {
+	log_to_stderr_only = 1;
+	foreground = 1;
+	break;
+      }
+
+    case 'r':
+      {
+	log_to_stderr_only = 1;
+	command = COM_RELOAD;
+	break;
+      }
+
+    case 'R':
+      {
+	log_to_stderr_only = 1;
+	command = COM_RESTART_COMPONENT;
+	break;
+      }
+
+    case 's':
+      {
+	log_to_stderr_only = 1;
+	command = COM_STATUS;
+	break;
+      }
+
+    case 'S':
+      {
+	log_to_stderr_only = 1;
+	command = COM_STOP;
+	break;
+      }
+
+    case OPT_DUMP_DEPMAP:
+      {
+	log_to_stderr_only = 1;
+	command = COM_DUMP_DEPMAP;
+	break;
+      }
+
+    case OPT_TRACE_DEPEND:
+      {
+	log_to_stderr_only = 1;
+	command = COM_TRACE_DEPEND;
+	break;
+      }
+
+    case OPT_TRACE_PREREQ:
+      {
+	log_to_stderr_only = 1;
+	command = COM_TRACE_PREREQ;
+	break;
+      }
+
+    case OPT_LIST_SHUTDOWN_SEQUENCE:
+      {
+	log_to_stderr_only = 1;
+	command = COM_LIST_SHUTDOWN_SEQUENCE;
+	break;
+      }
+
+    default:
+      po->po_error (po, PO_MSG_ERR,
+		    "internal error at %s:%d\n", __FILE__, __LINE__);
+      abort ();
+    }
+}
+
+static void
+pies_help_hook (WORDWRAP_FILE wf, struct parseopt *po)
+{
+  if (DEFAULT_PREPROCESSOR)
+    {
+      wordwrap_printf (wf,
+		       _("This pies preprocesses its configuration using %s\n"),
+		       DEFAULT_PREPROCESSOR);
+      wordwrap_printf (wf,
+		       _("Preprocessor include path: %s\n"),
+		       DEFAULT_INCLUDE_PATH);
+    }
+  else
+    wordwrap_printf (wf,
+		   _("This pies does not use configuration preprocessor.\n"));
+#ifdef INIT_EMU
+  wordwrap_para (wf);
+  wordwrap_puts (wf,
+		 "Notice: this program is compiled with init emulation code.");
+  wordwrap_para (wf);
+  wordwrap_flush (wf);
+  fputs (init_emu_help, stdout);
+#endif
+}
+
+extern void version_hook (WORDWRAP_FILE wf, struct parseopt *po);
+
+static struct parseopt po = {
+  .po_descr = N_("process invocation and execution supervisor"),
+  .po_optdef = optdef,
+  .po_setopt = setopt,
+  .po_package_name = PACKAGE_NAME,
+  .po_package_url = PACKAGE_URL,
+  .po_bugreport_address = PACKAGE_BUGREPORT,
+  .po_help_hook = pies_help_hook,
+  .po_version_hook = version_hook
+};
+
+void
+parse_options (int *pargc, char ***pargv)
+{
+  int argc = *pargc;
+  char **argv = *pargv;
+
+  if (SYSVINIT_ACTIVE)
+    {
+      sysvinit_parse_argv (argc, argv);
+      *pargc = 0;
+      *pargv = argv + argc;
+    }
+  else
+    {
+      if (parseopt_getopt (&po, argc, argv) == OPT_ERR)
+	{
+	  logmsg (LOG_CRIT, _("parseopt_getopt failed"));
+	  exit (EX_SOFTWARE);
+	}
+      parseopt_argv (&po, pargc, pargv);
+      parseopt_free (&po);
+      pp_init (incpath);
+    }
+}
+
 size_t pies_master_argc;
 char **pies_master_argv;
 
@@ -2494,7 +3054,7 @@ main (int argc, char **argv)
   set_quoting_style (NULL, shell_quoting_style);
 
   init_detect (argc, argv);
-  
+
   /* Set default logging */
   if (SYSVINIT_ACTIVE)
     {
@@ -2510,6 +3070,14 @@ main (int argc, char **argv)
 
   parse_options (&argc, &argv);
 
+#if PIES_SYSVINIT_ENABLED
+  if (pies_mode == MODE_TELINIT)
+    {
+      init_emu_fifo_setup ();
+      exit (telinit (argc, argv));
+    }
+#endif
+
   if (argc && !(command == COM_RESTART_COMPONENT
 		|| command == COM_TRACE_DEPEND
 		|| command == COM_TRACE_PREREQ))
@@ -2559,7 +3127,7 @@ main (int argc, char **argv)
   if (pies_envop)
     {
       environ_t *env;
-      
+
       if ((env = environ_create (environ)) == NULL)
 	{
 	  logmsg (LOG_CRIT, "environ_create: %s", strerror (errno));
@@ -2581,8 +3149,8 @@ main (int argc, char **argv)
 	  logmsg_printf (LOG_DEBUG, "\n");
 	}
     }
-  
-  if (lint_mode)
+
+  if (pies_mode == MODE_LINT)
     exit (0);
 
   /* Re-setup logging: it might have been reset in the config file */
@@ -2677,7 +3245,7 @@ main (int argc, char **argv)
       diag_setup (DIAG_TO_SYSLOG);
     }
 
-  logmsg (LOG_INFO, _("%s %s starting"), proginfo.package, proginfo.version);
+  logmsg (LOG_INFO, _("%s %s starting"), PACKAGE_NAME, PACKAGE_VERSION);
 
   if (!SYSVINIT_ACTIVE)
     {
@@ -2712,6 +3280,7 @@ main (int argc, char **argv)
 	  break;
 
 	case ACTION_RELOAD:
+	  pies_syslog_reload ();
 	  if (pies_reread_config ())
 	    {
 	      action = ACTION_CONT;
@@ -2788,7 +3357,7 @@ main (int argc, char **argv)
       execv (pies_master_argv[0], pies_master_argv);
     }
 
-  logmsg (LOG_INFO, _("%s %s terminated"), proginfo.package, proginfo.version);
+  logmsg (LOG_INFO, _("%s %s terminated"), PACKAGE_NAME, PACKAGE_VERSION);
   exit (EX_OK);
 }
 
