@@ -1,5 +1,5 @@
 /* This file is part of GNU Pies.
-   Copyright (C) 2008-2025 Sergey Poznyakoff
+   Copyright (C) 2008-2026 Sergey Poznyakoff
 
    GNU Pies is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -682,5 +682,5 @@ int ctl_open(void);
 void json_object_set_string (struct json_value *obj,
 			     char const *name, char const *fmt, ...);
 void json_object_set_number (struct json_value *obj,
-			     char const *name, double val);
+			     char const *name, long val);
 void json_object_set_bool (struct json_value *obj, char const *name, int val);
