@@ -1,5 +1,5 @@
 /* This file is part of GNU Pies.
-   Copyright (C) 2007-2021 Sergey Poznyakoff
+   Copyright (C) 2007-2026 Sergey Poznyakoff
 
    GNU Pies is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,13 +25,10 @@ void pies_syslog (int pri, char const *fmt, ...);
 void pies_vsyslog (int pri, char const *fmt, va_list ap);
 void pies_syslog_flush (void);
 void pies_syslog_message (int prio, char const *text, char const *tag, pid_t pid);
+void pies_syslog_reload (void);
 
 extern char *pies_fallback_file;
 extern char *pies_log_tag;
 extern int pies_log_facility;
 extern size_t pies_log_max_queue;
-
-
-
-
-
+extern int pies_fallback_ignore_failures;
