@@ -1,5 +1,5 @@
 /* This file is part of GNU Pies.
-   Copyright (C) 2007-2025 Sergey Poznyakoff
+   Copyright (C) 2007-2026 Sergey Poznyakoff
 
    GNU Pies is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -257,11 +257,11 @@ register_prog0 (struct component *comp)
     case pies_comp_startup:
     case pies_comp_shutdown:
       break;
-	  
+
     default:
       comp->redir[RETR_OUT].type = redir_null;
     }
-  
+
   link_prog (newp, find_prog_ref (comp));
   component_ref_incr (comp);
   return newp;
@@ -521,7 +521,6 @@ output_to_file (int fd, void *data)
 	{
 	  logmsg (LOG_INFO, _("%s: %s while reading %s"),
 		  tag, strerror (errno), retr_stream_name[rb->stream]);
-	  close (fd);
 	  deregister_socket (fd);
 	  return -1;
 	}
@@ -530,7 +529,6 @@ output_to_file (int fd, void *data)
     {
       debug (3, (_("%s: EOF on %s"),
 		 tag, retr_stream_name[rb->stream]));
-      close (fd);
       deregister_socket (fd);
     }
   else
@@ -543,7 +541,6 @@ output_to_file (int fd, void *data)
 	    {
 	      logmsg (LOG_INFO, _("%s: %s while reading %s"),
 		      tag, strerror (errno), retr_stream_name[rb->stream]);
-	      close (fd);
 	      deregister_socket (fd);
 	      return -1;
 	    }
@@ -552,7 +549,6 @@ output_to_file (int fd, void *data)
 	{
 	  debug (3, (_("%s: EOF writing %s"),
 		     tag, retr_stream_name[rb->stream]));
-	  close (fd);
 	  deregister_socket (fd);
 	  return -1;
 	}
@@ -638,7 +634,6 @@ output_syslog (int fd, void *data)
 	{
 	  logmsg (LOG_INFO, _("%s: %s while reading %s"),
 		  tag, strerror (errno), retr_stream_name[rb->stream]);
-	  close (fd);
 	  deregister_socket (fd);
 	  return -1;
 	}
@@ -647,7 +642,6 @@ output_syslog (int fd, void *data)
     {
       debug (3, (_("%s: EOF on %s"),
 		 tag, retr_stream_name[rb->stream]));
-      close (fd);
       deregister_socket (fd);
     }
   else
@@ -719,7 +713,7 @@ open_redirector (struct prog *master, int stream, int *fd)
     case redir_null:
       *fd = -1;
       break;
-      
+
     case redir_file:
       return redirect_to_file (master, stream, deansify, fd);
 
@@ -1053,7 +1047,7 @@ progman_ws_error (const char *fmt, ...)
   va_end (ap);
 }
 
-/* 
+/*
  * Initialization of the environment and argc/argv members of
  * struct prog.  For regular components this is done in the main
  * process, so that argv can be reported correctly via the ctl
@@ -1069,7 +1063,7 @@ prog_init (struct prog *prog)
       logmsg (LOG_CRIT, "environ_create: %s", strerror (errno));
       return -1;
     }
-  
+
   if (prog->v.p.comp->flags & CF_SOCKENV)
     {
       size_t i;
@@ -1079,10 +1073,10 @@ prog_init (struct prog *prog)
 
   if (envop_exec (prog->v.p.comp->envop, prog->v.p.env))
     {
-      logmsg (LOG_CRIT, "environ_exec: %s", strerror (errno));
+      logmsg (LOG_CRIT, "envop_exec: %s", strerror (errno));
       return -1;
     }
-  
+
   if (SYSVINIT_ACTIVE)
     {
       size_t i;
@@ -1093,9 +1087,9 @@ prog_init (struct prog *prog)
 	      logmsg (LOG_CRIT, "environ_add: %s", strerror (errno));
 	      return -1;
 	    }
-	}	      
+	}
     }
-  debug_environ (prog, 4);  
+  debug_environ (prog, 4);
 
   if (prog->v.p.comp->flags & CF_EXPANDENV)
     {
@@ -1111,7 +1105,7 @@ prog_init (struct prog *prog)
 	  return -1;
 	}
       wordsplit_get_words (&ws, &prog->v.p.argc, &prog->v.p.argv);
-      wordsplit_free (&ws);      
+      wordsplit_free (&ws);
     }
   else
     {
@@ -1165,7 +1159,7 @@ prog_execute (struct prog *prog)
   execvp (prog->v.p.comp->program ?
 	  prog->v.p.comp->program : prog->v.p.argv[0],
 	  prog->v.p.argv);
-  //FIXME: pies_syslog?  
+  //FIXME: pies_syslog?
   syslog (LOG_CRIT, _("cannot start `%s': %s"), prog_tag (prog),
 	  strerror (errno));
   _exit (EX_SOFTWARE);
@@ -1277,7 +1271,7 @@ prog_start (struct prog *prog)
 
   if (prog_init (prog))
     return; //FIXME
-  
+
   redir[RETR_OUT] = open_redirector (prog, RETR_OUT,
 				     &prog->v.p.redir[RETR_OUT]);
   redir[RETR_ERR] = open_redirector (prog, RETR_ERR,
@@ -1363,7 +1357,7 @@ prog_start (struct prog *prog)
 
       /* Close unneeded descripitors */
       pies_close_fds ((prog->v.p.comp->mode == pies_comp_pass_fd
-	               ? prog->v.p.socket : 2) + 1);
+		       ? prog->v.p.socket : 2) + 1);
 
       prog_execute (prog);
 
@@ -2256,13 +2250,13 @@ static int
 status_matches_p (struct action *act, unsigned status)
 {
   int result;
-  
+
   if (act->cond_list == NULL)
     result = 1;
   else
     {
       struct grecs_list_entry *ep;
-      
+
       for (ep = act->cond_list->head; ep; ep = ep->next)
 	{
 	  struct status_cond *cp = ep->data;
@@ -2280,7 +2274,7 @@ status_matches_p (struct action *act, unsigned status)
 	    break;
 	}
     }
-  
+
   return result;
 }
 
@@ -2485,7 +2479,20 @@ progman_cleanup (int flags)
 				   prog_tag (prog), pid, "");
 
 		  prog->v.p.status = status_stopped;
+
+		  /*
+		   * Free resources which are initialized on each startup.
+		   */
+		  environ_free (prog->v.p.env);
+		  prog->v.p.env = NULL;
+		  if (prog->v.p.comp->flags & CF_EXPANDENV)
+		    {
+		      argv_free (prog->v.p.argv);
+		      prog->v.p.argv = NULL;
+		      prog->v.p.argc = 0;
+		    }
 		  prog_stop_redirectors (prog);
+
 		  prog_stop_dependents (prog);
 		  if (!expect_term && component_is_active (prog->v.p.comp))
 		    react (prog, status, pid);
@@ -2662,7 +2669,7 @@ progman_gc (void)
 	return;
     }
   while (!timeout_expired (&ts));
-  
+
   /* Kill the remaining programs with SIGKILL */
   diagmsg (DIAG_CON, LOG_INFO, "Sending processes the KILL signal");
   while ((prog = prog_to_stop (next)) != NULL)
@@ -2748,7 +2755,7 @@ progman_stop (void)
   unsigned long *ordv;
   size_t ordc;
   size_t i;
-  int sd;
+  int sd = 0;
 
   /*
    * Stop all running components in correct order (dependents first).
@@ -2791,6 +2798,7 @@ progman_stop (void)
 	  progman_cleanup (CLEANUP_EXPECT_TERM);
 	}
     }
+  free (ordv);
 }
 
 /* EOF */
