@@ -1,5 +1,5 @@
 /* This file is part of GNU Pies.
-   Copyright (C) 2013-2025 Sergey Poznyakoff
+   Copyright (C) 2013-2026 Sergey Poznyakoff
 
    GNU Pies is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 #include "prog.h"
 #include <sys/ioctl.h>
 #include <termios.h>
+#include "parseopt.h"
 
 enum boot_state
   {
@@ -45,13 +46,13 @@ static int boot_trans_tab[max_boot_state][sizeof(valid_runlevels)-1]  = {
   /*                    0,       1,       2,       3,       4,             */
   /*                         5,       6,       7,       8,       9,      S */
   /* sysinit */ {    boot,    boot,    boot,    boot,    boot,
-                          boot,    boot,    boot,    boot,    boot, single },
+			  boot,    boot,    boot,    boot,    boot, single },
   /* boot    */ {  normal,  normal,  normal,  normal,  normal,
-                        normal,  normal,  normal,  normal,  normal, normal },
+			normal,  normal,  normal,  normal,  normal, normal },
   /* single  */ {    boot,    boot,    boot,    boot,    boot,
-                          boot,    boot,    boot,    boot,    boot, single },
+			  boot,    boot,    boot,    boot,    boot, single },
   /* normal  */ {  normal,  normal,  normal,  normal,  normal,
-                        normal,  normal,  normal,  normal,  normal, normal },
+			normal,  normal,  normal,  normal,  normal, normal },
 };
 
 enum boot_state boot_state;
@@ -74,10 +75,10 @@ console_open (int mode)
     {
       fd = open (console_device, mode | O_NONBLOCK);
       if (fd >= 0)
-        {
-          fcntl (fd, F_SETFL, mode);
-          return fd;
-        }
+	{
+	  fcntl (fd, F_SETFL, mode);
+	  return fd;
+	}
     }
   return -1;
 }
@@ -138,61 +139,61 @@ askrunlevel (void)
   char c, lvl = -1;
   enum { srl_init, srl_char, srl_r, srl_n, srl_skip } srl = srl_init;
   static const char prompt[] = "\nEnter runlevel: ";
-  
+
   console_stty ();
   fd = console_open (O_RDWR|O_NOCTTY);
   if (fd == -1)
     return 'S';
-  
+
   while (1)
     {
       if (srl == srl_init)
-        {
-          write (fd, prompt, sizeof (prompt) - 1);
-          if (read (fd, &lvl, 1) != 1)
-            return 'S';
-          srl = srl_char;
-        }
+	{
+	  write (fd, prompt, sizeof (prompt) - 1);
+	  if (read (fd, &lvl, 1) != 1)
+	    return 'S';
+	  srl = srl_char;
+	}
       else if (srl == srl_n)
-        {
-          if (is_valid_runlevel (lvl))
-            break;
-          srl = srl_init;
-        }
+	{
+	  if (is_valid_runlevel (lvl))
+	    break;
+	  srl = srl_init;
+	}
       else
-        {
-          if (read (fd, &c, 1) != 1)
-            {
-              if (!is_valid_runlevel (lvl))
-                lvl = 'S';
-              break;
-            }
-          
-          switch (srl)
-            {
-            case srl_char:
-              if (c == '\r')
-                srl = srl_r;
-              else if (c == '\n')
-                srl = srl_n;
-              else
-                srl = srl_skip;
-              break;
+	{
+	  if (read (fd, &c, 1) != 1)
+	    {
+	      if (!is_valid_runlevel (lvl))
+		lvl = 'S';
+	      break;
+	    }
 
-            case srl_r:
-              if (c == '\n')
-                srl = srl_n;
-              else
-                srl = srl_skip;
-              break;
+	  switch (srl)
+	    {
+	    case srl_char:
+	      if (c == '\r')
+		srl = srl_r;
+	      else if (c == '\n')
+		srl = srl_n;
+	      else
+		srl = srl_skip;
+	      break;
 
-            case srl_skip:
-              if (c == '\n')
-                srl = srl_init;
+	    case srl_r:
+	      if (c == '\n')
+		srl = srl_n;
+	      else
+		srl = srl_skip;
+	      break;
+
+	    case srl_skip:
+	      if (c == '\n')
+		srl = srl_init;
 	    default:
 	      break;
-            }
-        }
+	    }
+	}
     }
   close (fd);
   return toupper (lvl);
@@ -211,7 +212,7 @@ runlevel_index (int n)
 
   if (n == 0)
     return -1;
-  
+
   p = strchr (valid_runlevels, n);
   if (!p)
     return -1;
@@ -233,49 +234,49 @@ enablecomp (struct prog *prog, void *data)
     {
     case sysinit:
       return comp->mode == pies_comp_sysinit;
-          
+
     case boot:
       return comp->mode == pies_comp_boot || comp->mode == pies_comp_bootwait;
-          
+
     case single:
     case normal:
       switch (comp->mode)
-        {
-        case pies_comp_sysinit:
-        case pies_comp_boot:
-        case pies_comp_bootwait:
-          return 0;
+	{
+	case pies_comp_sysinit:
+	case pies_comp_boot:
+	case pies_comp_bootwait:
+	  return 0;
 
 	case pies_comp_ondemand:
 	  /* Active flag persists: */
 	  return prog->active;
-	  
-        case pies_comp_powerfail:
-        case pies_comp_powerwait:
-        case pies_comp_powerokwait:
-        case pies_comp_ctrlaltdel:
-        case pies_comp_powerfailnow:
-        case pies_comp_kbrequest:
+
+	case pies_comp_powerfail:
+	case pies_comp_powerwait:
+	case pies_comp_powerokwait:
+	case pies_comp_ctrlaltdel:
+	case pies_comp_powerfailnow:
+	case pies_comp_kbrequest:
 	  return s && (s->mask & PIES_COMP_MASK (comp->mode));
 
 	default:
 	  break;
-        } 
+	}
     }
 
   if (!comp->runlevels)
     return -1;
-  
+
   if (!strchr (comp->runlevels, runlevel))
     {
       if (prog->v.p.status == status_finished && comp->mode != pies_comp_once)
 	prog->v.p.status = status_stopped;
       return 0;
     }
-  
+
   if (prog->v.p.status == status_finished)
     return -1;
-  
+
   return 1;
 }
 
@@ -288,7 +289,7 @@ runlevel_setup_prog (struct prog *prog, void *data)
     {
       int rc = enablecomp (prog, data);
       if (rc < 0 || prog->active == rc)
-        return 0;
+	return 0;
       prog->active = rc;
       if (rc)
 	prog->wait = is_comp_wait (prog->v.p.comp);
@@ -296,8 +297,8 @@ runlevel_setup_prog (struct prog *prog, void *data)
 	       && prog->v.p.status != status_finished)
 	prog->stop = 1;
       debug (2, ("%s: %s%s", prog_tag (prog),
-                 prog->active ?
-                 "enabled" : "disabled",
+		 prog->active ?
+		 "enabled" : "disabled",
 		 prog->active && prog->wait ? " (wait)" : ""));
     }
   return 0;
@@ -326,7 +327,7 @@ demand_prog (struct prog *prog, void *data)
     }
   return 0;
 }
-      
+
 static void
 sysvinit_demand (int rl)
 {
@@ -375,23 +376,23 @@ envsetup (void)
     {
       char *str = sysvinit_environ_hint[i];
       switch (i)
-        {
-        case ENVI_PREVLEVEL:
-          str[strlen (str) - 1] = prevlevel;
-          break;
+	{
+	case ENVI_PREVLEVEL:
+	  str[strlen (str) - 1] = prevlevel;
+	  break;
 
-        case ENVI_RUNLEVEL:
-          str[strlen (str) - 1] =
-            boot_state_str[boot_state] == ' ' ?
-              (runlevel ? runlevel : '#') : boot_state_str[boot_state];
-          break;
+	case ENVI_RUNLEVEL:
+	  str[strlen (str) - 1] =
+	    boot_state_str[boot_state] == ' ' ?
+	      (runlevel ? runlevel : '#') : boot_state_str[boot_state];
+	  break;
 
-        case ENVI_CONSOLE:
-          if (strlen (console_device) >= sizeof (ENVTMPL_CONSOLE))
-            logmsg (LOG_ERR, "console device name too long");
-          else
-            strcpy (str + sizeof (ENVAR_CONSOLE) - 1, console_device);
-        }
+	case ENVI_CONSOLE:
+	  if (strlen (console_device) >= sizeof (ENVTMPL_CONSOLE))
+	    logmsg (LOG_ERR, "console device name too long");
+	  else
+	    strcpy (str + sizeof (ENVAR_CONSOLE) - 1, console_device);
+	}
     }
 }
 
@@ -414,13 +415,13 @@ sysvinit_envlocate (char const *name, char **value)
     }
   return -1;
 }
-	  
+
 int
 sysvinit_envupdate (char const *var)
 {
   int i, j;
   size_t len;
-  
+
   len = strcspn (var, "=");
   for (i = 0; i < NR_ENVHINT; i++)
     {
@@ -473,7 +474,7 @@ sysvinit_set_runlevel (int newlevel)
 	       "Activating on-demand level '%c'", newlevel);
       sysvinit_demand (newlevel);
       break;
-			  
+
     default:
       if (newlevel == runlevel)
 	break;
@@ -510,7 +511,7 @@ sysvinit_fifo_handler (int fd, void *data)
   if (rc == -1)
     {
       logmsg (LOG_ERR, _("error reading from %s: %s"), init_fifo,
-              strerror (errno));
+	      strerror (errno));
       size = 0;
       return 0;
     }
@@ -528,20 +529,20 @@ sysvinit_fifo_handler (int fd, void *data)
   if (size == sizeof (struct sysvinit_request))
     {
       if (buf.req.magic != INIT_MAGIC)
-        logmsg (LOG_ERR, _("got invalid initreq"));
+	logmsg (LOG_ERR, _("got invalid initreq"));
       else
-        {
-          debug (1, ("INITREQ: cmd=%d, runlevel=%d, sleeptime=%d",
-                     buf.req.cmd, buf.req.runlevel, buf.req.sleeptime));
+	{
+	  debug (1, ("INITREQ: cmd=%d, runlevel=%d, sleeptime=%d",
+		     buf.req.cmd, buf.req.runlevel, buf.req.sleeptime));
 	  if (buf.req.sleeptime > 0)
 	    shutdown_timeout = buf.req.sleeptime;
-          switch (buf.req.cmd)
-            {
-            case INIT_CMD_RUNLVL:
-              buf.req.runlevel = toupper (buf.req.runlevel);
+	  switch (buf.req.cmd)
+	    {
+	    case INIT_CMD_RUNLVL:
+	      buf.req.runlevel = toupper (buf.req.runlevel);
 	      switch (buf.req.runlevel)
 		{
-		case 'Q':	
+		case 'Q':
 		  pies_schedule_action (ACTION_RELOAD);
 		  break;
 
@@ -553,22 +554,22 @@ sysvinit_fifo_handler (int fd, void *data)
 	    case INIT_CMD_SETENV:
 	      sysvinit_setenv (buf.req.data, sizeof (buf.req.data));
 	      break;
-	      
+
 	    case INIT_CMD_POWERFAIL:
 	      powerfailcmd (POWER_STAT_FAIL);
 	      break;
-	      
+
 	    case INIT_CMD_POWERFAILNOW:
 	      powerfailcmd (POWER_STAT_LOW);
 	      break;
-	      
+
 	    case INIT_CMD_POWEROK:
 	      powerfailcmd (POWER_STAT_OK);
 	      break;
 
-              /* FIXME: react on other commands */
-            }
-        }
+	      /* FIXME: react on other commands */
+	    }
+	}
       size = 0;
     }
   return 0;
@@ -583,25 +584,25 @@ create_fifo (void)
   if (stat (init_fifo, &st) < 0)
     {
       if (errno != ENOENT)
-        {
-          logmsg (LOG_ERR, "cannot stat fifo %s: %s", init_fifo,
-                  strerror (errno));
-          return;
-        }
+	{
+	  logmsg (LOG_ERR, "cannot stat fifo %s: %s", init_fifo,
+		  strerror (errno));
+	  return;
+	}
       else if (mkfifo (init_fifo, 0600))
-        {
-          logmsg (LOG_ERR, "cannot create fifo %s: %s", init_fifo,
-                  strerror (errno));
-          return;
-        }
+	{
+	  logmsg (LOG_ERR, "cannot create fifo %s: %s", init_fifo,
+		  strerror (errno));
+	  return;
+	}
     }
   else
     {
       if (!S_ISFIFO (st.st_mode))
-        {
-          logmsg (LOG_ERR, "not a fifo: %s", init_fifo);
-          return;
-        }
+	{
+	  logmsg (LOG_ERR, "not a fifo: %s", init_fifo);
+	  return;
+	}
 
       chmod (init_fifo, 0600);
     }
@@ -610,10 +611,10 @@ create_fifo (void)
     {
       fstat (fd, &fst);
       if (fst.st_dev != st.st_dev || fst.st_ino != st.st_ino)
-        deregister_socket (fd);
+	deregister_socket (fd);
       debug (1, ("reopening %s", init_fifo));
     }
-  
+
   /* Opening the socket in read-write mode ensures we won't get EOF
      on it when the caller party closes connection (at least on Linux).
      Nevertheless, the svinit_fifo_handler is prepared for that eventuality,
@@ -622,7 +623,7 @@ create_fifo (void)
   if (fd == -1)
     {
       logmsg (LOG_ERR, "cannot open %s: %s", init_fifo,
-              strerror (errno));
+	      strerror (errno));
       return;
     }
   register_socket (fd, sysvinit_fifo_handler, NULL, NULL, NULL, NULL);
@@ -638,16 +639,16 @@ set_console_dev (void)
   for (i = 0; i < ARRAY_SIZE (try_console); i++)
     {
       if (try_console[i])
-        {
-          int fd = open (try_console[i], O_RDONLY|O_NONBLOCK);
+	{
+	  int fd = open (try_console[i], O_RDONLY|O_NONBLOCK);
 
-          if (fd >= 0)
-            {
-              close (fd);
-              console_device = try_console[i];
-              return;
-            }
-        }
+	  if (fd >= 0)
+	    {
+	      close (fd);
+	      console_device = try_console[i];
+	      return;
+	    }
+	}
     }
   /* provide default */
   console_device = "/dev/null";
@@ -716,9 +717,9 @@ start_shell (const char *shell)
 
       signal_setup (SIG_DFL);
       setsid ();
-      
+
       fd = console_open (O_RDWR|O_NOCTTY);
-      if (fd < 0) 
+      if (fd < 0)
 	{
 	  logmsg (LOG_CRIT, "open(%s): %s",
 		  console_device, strerror (errno));
@@ -731,11 +732,11 @@ start_shell (const char *shell)
       execl (shell, shell, NULL);
       _exit (127);
     }
-  
+
   while ((rc = wait (&st)) != pid)
     if (rc == (pid_t) -1 && errno == ECHILD)
       break;
-  
+
   logmsg (LOG_CRIT, "shell finished");
   sigaction (SIGCHLD, &old, NULL);
 }
@@ -794,7 +795,7 @@ sysvinit_begin (void)
 
   grecs_malloc_fun  = sysvinit_malloc;
   grecs_realloc_fun = sysvinit_realloc;
-  
+
   close (0);
   close (1);
   close (2);
@@ -824,27 +825,27 @@ inittrans (void)
   enum boot_state newstate;
   int trans = 0;
   int userchg = 0;
-  
+
   if (progman_waiting_p ())
     /* Noting to do if there are processes left in the previous runlevel */
     return 0;
-  
+
   if (runlevel == 0)
     n = runlevel_index (dfl_level ? dfl_level : getinitdefault ());
   else
     n = runlevel_index (runlevel);
   if (n == -1)
     n = runlevel_index ('S');
-  
+
   newstate = boot_trans_tab[boot_state][n];
   if (newstate != boot_state)
     {
       debug (1, ("STATE TRANS: %s -> %s", boot_state_name[boot_state],
-                 boot_state_name[newstate]));
+		 boot_state_name[newstate]));
       boot_state = newstate;
       trans = 1;
     }
-  
+
   switch (boot_state)
     {
     case sysinit:
@@ -872,7 +873,7 @@ inittrans (void)
       prevlevel = runlevel ? runlevel : 'N';
       debug (1, ("RL TRANS: %c -> %c", prevlevel, newlevel));
       sysvinit_acct (SYSV_ACCT_RUNLEVEL, "runlevel", "~~",
-                     newlevel + 256 * runlevel, "~");
+		     newlevel + 256 * runlevel, "~");
       mf_proctitle_format ("init [%c]", newlevel);
       runlevel = newlevel;
       trans = 1;
@@ -881,7 +882,7 @@ inittrans (void)
   if (trans)
     {
       envsetup ();
-      
+
       if (userchg)
 	pies_schedule_action (ACTION_RELOAD);
       else
@@ -914,7 +915,108 @@ is_comp_wait (struct component *comp)
   return 0;
 }
 
-#include "telinit.h"
+struct sysvinit_env_closure
+{
+  struct sysvinit_request *req;
+  size_t envsize;
+};
+
+static int
+optset_env (struct parseopt *po, struct optdef *opt, char *arg)
+{
+  struct sysvinit_env_closure *ext = po->po_hook_data;
+  size_t len = strlen (arg);
+  if (ext->envsize + len + 2 > sizeof (ext->req->data))
+    {
+      po->po_error (po, PO_MSG_ERR, _("argument to %s%s too long"),
+		    option_dash (po, opt), opt->opt_name);
+      exit (EX_USAGE);
+    }
+  memcpy (ext->req->data + ext->envsize, arg, len);
+  ext->envsize += len;
+  ext->req->data[ext->envsize++] = 0;
+  return 0;
+}
+
+static struct optdef options[] = {
+  {
+    .opt_name = "timeout",
+    .opt_argdoc = N_("SECONDS"),
+    .opt_doc = N_("set interval between sending TERM and KILL signals"),
+    .opt_set = optset_ulong,
+    .opt_ptr = &shutdown_timeout
+  },
+  {
+    .opt_name = "t",
+    .opt_flags = OPTFLAG_ALIAS
+  },
+
+  {
+    .opt_name = "environment",
+    .opt_argdoc = N_("VAR=[VAL]"),
+    .opt_doc = N_("change environment"),
+    .opt_set = optset_env
+  },
+  {
+    .opt_name = "e",
+    .opt_flags = OPTFLAG_ALIAS
+  },
+
+  { NULL }
+}, *optdef[] = { options, NULL };
+
+static struct parseopt po = {
+  .po_descr = "send command to init process via the legacy interface",
+  .po_argdoc = "-T [OPTIONS] [RUNLEVEL]",
+  .po_optdef = optdef,
+  .po_flags = PARSEOPT_ARGV0,
+  .po_package_name = PACKAGE_NAME,
+  .po_package_url = PACKAGE_URL,
+  .po_bugreport_address = PACKAGE_BUGREPORT,
+};
+
+static void
+telinit_parser (struct sysvinit_request *req, int argc, char *argv[])
+{
+  struct sysvinit_env_closure envc = { req, 0 };
+
+  po.po_program_name = (char*) program_name;
+  po.po_hook_data = &envc;
+  if (parseopt_getopt (&po, argc, argv) == OPT_ERR)
+    {
+      logmsg (LOG_CRIT, _("parseopt_getopt failed"));
+      exit (EX_SOFTWARE);
+    }
+  parseopt_argv (&po, &argc, &argv);
+  parseopt_free (&po);
+
+  if (envc.envsize)
+    {
+      req->data[envc.envsize++] = 0;
+      req->cmd = INIT_CMD_SETENV;
+      if (argc)
+	{
+	  logmsg (LOG_ERR, _("too many arguments"));
+	  exit (EX_USAGE);
+	}
+    }
+  else
+    {
+      if (argc != 1)
+	{
+	  logmsg (LOG_ERR, _("bad number of arguments"));
+	  exit (EX_USAGE);
+	}
+      if (argv[0][1] || !is_valid_runlevel (argv[0][0]))
+	{
+	  logmsg (LOG_ERR, _("invalid runlevel: %s"), argv[0]);
+	  exit (EX_USAGE);
+	}
+      req->cmd = INIT_CMD_RUNLVL;
+      req->runlevel = argv[0][0];
+      req->sleeptime = shutdown_timeout;
+    }
+}
 
 int
 telinit (int argc, char **argv)
@@ -938,7 +1040,7 @@ telinit (int argc, char **argv)
   if (write (fd, &req, sizeof (req)) != sizeof (req))
     {
       logmsg (LOG_ERR, _("error writing to %s: %s"),
-              init_fifo, strerror (errno));
+	      init_fifo, strerror (errno));
       return EX_UNAVAILABLE;
     }
   alarm (0);
@@ -978,7 +1080,7 @@ static struct action_parser action_tab[] = {
   { "powerfail",    pies_comp_powerfail },
   { "powerwait",    pies_comp_powerwait },
   { "powerokwait",  pies_comp_powerokwait },
-  { "ctrlaltdel",   pies_comp_ctrlaltdel },	
+  { "ctrlaltdel",   pies_comp_ctrlaltdel },
   { "ondemand",     pies_comp_ondemand },
   { "sysinit",      pies_comp_sysinit },
   { "powerfailnow", pies_comp_powerfailnow },
@@ -1029,14 +1131,14 @@ inittab_parse_line (struct inittab_ctx *ctx)
   struct action_parser *ap;
   struct component *comp;
   struct wordsplit ws;
-      
+
   ctx->line_no++;
   for (p = ctx->buf; *p && c_isblank (*p); p++)
     ;
 
   if (!p || *p == '\n')
     return inittab_ok;
-  
+
   if (*p == '#')
     {
       if (wordsplit (p+1, &ws, WRDSF_DEFFLAGS))
@@ -1062,7 +1164,7 @@ inittab_parse_line (struct inittab_ctx *ctx)
 		{
 		  struct config_syntax *synt =
 		    str_to_config_syntax (ws.ws_wordv[3]);
-		      
+
 		  if (!synt)
 		    logmsg (LOG_ERR, "%s:%u: %s",
 			    ctx->file, ctx->line_no, _("unknown syntax type"));
@@ -1078,11 +1180,11 @@ inittab_parse_line (struct inittab_ctx *ctx)
 	      return inittab_stop;
 	    }
 	}
-      
+
       wordsplit_free (&ws);
       return inittab_ok;
-    }    
-      
+    }
+
   id = getfld (p, &p);
   runlevels = getfld (p, &p);
   action = getfld (p, &p);
@@ -1119,7 +1221,7 @@ inittab_parse_line (struct inittab_ctx *ctx)
 	      _("unknown action"));
       return inittab_err;
     }
-      
+
   comp = component_create (id);
   comp->mode = ap->mode;
   comp->runlevels = grecs_strdup (strupr (runlevels));
@@ -1136,7 +1238,7 @@ inittab_parse_line (struct inittab_ctx *ctx)
   wordsplit_free (&ws);
 
   comp->flags |= CF_SIGGROUP;
-      
+
   if (ap->parser && ap->parser (comp, ctx->file, ctx->line_no))
     {
       component_free (comp);
@@ -1158,12 +1260,12 @@ inittab_parse (const char *file)
   FILE *fp;
   struct inittab_ctx ctx;
   int err;
-  
+
   ctx.size = 0;
   ctx.buf = NULL;
   ctx.file = file;
   ctx.line_no = 0;
-  
+
   fp = fopen (file, "r");
   if (fp)
     {
@@ -1193,12 +1295,12 @@ inittab_parse (const char *file)
       grecs_asprintf (&ctx.buf, &ctx.size, "~~:S:wait:%s\n", emergency_shell);
       inittab_parse_line (&ctx);
     }
-  
+
   free (ctx.buf);
   return err;
 }
 
-char *power_stat_file = POWER_STAT_FILE; 
+char *power_stat_file = POWER_STAT_FILE;
 
 void
 sysvinit_power (void)
@@ -1238,22 +1340,22 @@ static void
 powerfailcmd (int power_stat)
 {
   int mask;
-  
+
   switch (power_stat)
     {
     case POWER_STAT_OK: /* The power is OK */
       mask = PIES_COMP_MASK (pies_comp_powerokwait);
       break;
-      
+
     case POWER_STAT_LOW: /* Low battery: shut down now */
       mask = PIES_COMP_MASK (pies_comp_powerfailnow);
       break;
-      
+
     default: /* Power failure */
       mask = PIES_COMP_MASK (pies_comp_powerfail)
 	     | PIES_COMP_MASK (pies_comp_powerwait);
     }
-	
+
   sysvinit_runlevel_setup (mask);
 }
 
@@ -1281,7 +1383,7 @@ sysvinit_parse_argv (int argc, char **argv)
 	emergency = 1;
       else if (!arg[1] && strchr (valid_runlevels, (c = toupper (arg[0]))))
 	dfl_level = c;
-    }	  
+    }
 }
 
 int
@@ -1332,4 +1434,3 @@ cb_runlevels (enum grecs_callback_command cmd,
     *p = toupper (*p);
   return 0;
 }
-
